==> platformio_4.3.4.orig.tar.gz: platformio-4.3.4/examples/platforms/sifive/README.md <==

# SiFive: development platform for [PlatformIO](https://platformio.org)

SiFive brings the power of open source and software automation to the semiconductor industry, making it possible to develop new hardware faster and more affordably than ever before. 

* [Home](https://platformio.org/platforms/sifive) (home page in PlatformIO Registry)
* [Documentation](https://docs.platformio.org/page/platforms/sifive.html) (advanced usage, packages, boards, frameworks, etc.)

# Examples

* [freedom-e-sdk_hello](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_hello)
* [freedom-e-sdk_multicore-hello](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_multicore-hello)
* [freedom-e-sdk_sifive-welcome](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_sifive-welcome)
* [freedom-e-sdk_spi](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_spi)
* [freedom-e-sdk_test-coreip](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_test-coreip)
* [freedom-e-sdk_timer-interrupt](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_timer-interrupt)
* [freedom-e-sdk_user-mode](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_user-mode)
* [freedom-e-sdk_user-syscall](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_user-syscall)
* [native-blink_asm](https://github.com/platformio/platform-sifive/tree/master/examples/native-blink_asm)
* [zephyr-blink](https://github.com/platformio/platform-sifive/tree/master/examples/zephyr-blink)
* [zephyr-hello-world](https://github.com/platformio/platform-sifive/tree/master/examples/zephyr-hello-world)
* [zephyr-synchronization](https://github.com/platformio/platform-sifive/tree/master/examples/zephyr-synchronization)

==> platformio_6.1.10.orig.tar.gz: platformio-6.1.10/examples/platforms/sifive/README.md <==

# SiFive: development platform for [PlatformIO](https://platformio.org)

SiFive brings the power of open source and software automation to the semiconductor industry, making it possible to develop new hardware faster and more affordably than ever before. 

* [Home](https://platformio.org/platforms/sifive) (home page in PlatformIO Registry)
* [Documentation](https://docs.platformio.org/page/platforms/sifive.html) (advanced usage, packages, boards, frameworks, etc.)

# Examples

* [freedom-e-sdk_freertos-blinky](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_freertos-blinky)
* [freedom-e-sdk_freertos-blinky-system-view](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_freertos-blinky-system-view)
* [freedom-e-sdk_freertos-pmp-blinky](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_freertos-pmp-blinky)
* [freedom-e-sdk_hello](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_hello)
* [freedom-e-sdk_multicore-hello](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_multicore-hello)
* [freedom-e-sdk_sifive-welcome](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_sifive-welcome)
* [freedom-e-sdk_spi](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_spi)
* [freedom-e-sdk_test-coreip](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_test-coreip)
* [freedom-e-sdk_timer-interrupt](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_timer-interrupt)
* [freedom-e-sdk_user-mode](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_user-mode)
* [freedom-e-sdk_user-syscall](https://github.com/platformio/platform-sifive/tree/master/examples/freedom-e-sdk_user-syscall)
* [native-blink_asm](https://github.com/platformio/platform-sifive/tree/master/examples/native-blink_asm)
* [zephyr-blink](https://github.com/platformio/platform-sifive/tree/master/examples/zephyr-blink)
* [zephyr-hello-world](https://github.com/platformio/platform-sifive/tree/master/examples/zephyr-hello-world)
* [zephyr-synchronization](https://github.com/platformio/platform-sifive/tree/master/examples/zephyr-synchronization)
